FlutlyBottomBarItem class

Constructors

FlutlyBottomBarItem({required FlutlyPage page, Widget? activePath, Widget? deactivePath, List<FlutlyBottomBarItem>? children, Widget? leading, double? leadingHeight, FlutlyTransactionType? transactionType})

Properties

activePath Widget?
getter/setter pair
children List<FlutlyBottomBarItem>?
getter/setter pair
deactivePath Widget?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
leading Widget?
getter/setter pair
leadingHeight double?
getter/setter pair
page FlutlyPage
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionType FlutlyTransactionType?
getter/setter pair

Methods

getActivePath() Widget
getDeactivePath() Widget
getLeadingHeight() double
getTransactionType() FlutlyTransactionType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited